# WOdEv
Week Odd (or) Even

A useful tool for people who label odd/even weeks in their schedule.

The default calendar is [Jalali](https://en.wikipedia.org/wiki/Jalali_calendar).

## Getting Started

### Prerequisites

* Python3 (>= 3.6)
* pip3

### Install

```bash
pip install wodev
```

## Usage

```bash
$ woodev

# e.g. output:
# first week: 1400-06-22,
# today: 1400-06-26,
# odev: ODD
```

## Roadmap

See the [open issues](https://github.com/MohammadSalek/WOdEv/issues) for a list of proposed features (and known issues).
